# bpy-build
Python build script for Blender as a python module

It needs to be its own repository to satisfy the `install_requires` of blenderpy

It is important to note that this is a toolset to build your own Blender build scripts. It does not create builds for you. It just generates the build script.
